#ifndef _DOWNLOADER_H
#define _DOWNLOADER_H

#include <QNetworkReply>
#include <QObject>

class QNetworkAccessManager;
class QNetworkRequest;


// A simple object that handles HTTP(S) GET/POST requests, sending the fetched via a
// signal (downloadFinished()) when complete. Only a single object at once.
class Downloader : public QObject {
    Q_OBJECT

public:
    ~Downloader();

    void startDownload(QNetworkRequest* request, QByteArray* postData);

    // Signal-handlers for the connected QNetworkReply.
    void httpRead();
    void httpProgress(qint64 received, qint64 total);
    void httpError(QNetworkReply::NetworkError code);
    void httpFinished();

signals:
    void downloadFinished(QByteArray* data);
    void downloadError(QString message);
    void downloadProgress(bool connected, QString text);

private:
    QByteArray* fetchedData;
    QNetworkAccessManager netManager;
    QNetworkReply* netReply;
};


#endif // _DOWNLOADER_H
