#ifndef _NETADDRESSER_H
#define _NETADDRESSER_H

#include "addresser.h"

class QByteArray;
class QNetworkRequest;

class Downloader;


// A class for all Addressers that use HTTP APIs, adding a generic interface for
// downloading and parsing the relevant data.
class NetAddresser : public Addresser {
    Q_OBJECT

public:
    NetAddresser();
    ~NetAddresser();

    virtual void locateAddress(QString address);

    // This is the function responsible for parsing received data; it must at some point
    // emit Address::locationFound, Address::locationError, or Address:locationCancelled.
    virtual void parseCoordinatesFromResponse(QByteArray* data) = 0;

    void downloadError(QString message);

protected:
    // This must be implemented, to create the QNetworkRequest used for the download,
    // containing the appropriate URL and header data.
    virtual QNetworkRequest* makeLocatingRequest(QString address) = 0;

    // This should be implemented, returning non-nullptr if the HTTP request will be
    // POST rather than GET. The returned data will be used as POST data.
    virtual QByteArray* makePostData(QString address) { return nullptr; }

    Downloader* downloader;
};


#endif // _NETADDRESSER_H
