#ifndef _NETROUTER_H
#define _NETROUTER_H

#include <QNetworkReply>

#include "router.h"

class QNetworkAccessManager;
class QNetworkRequest;

class Downloader;


// A class for all Routers that use HTTP APIs, adding a generic interface for
// downloading and parsing the relevant data.
class NetRouter : public Router {
    Q_OBJECT

public:
    NetRouter();
    ~NetRouter();

    // This method is required to be implemented by Router, and is invoked by
    // Router::calculateDistances, for Routers where the the distance matrix is
    // calculated one-cell-at-a-time. Since the NetRouters receive the distance
    // matrix directly, we override both calculateDistances and this method.
    virtual int pointDistance(double from_latitude, double from_longitude,
			      double to_latitude, double to_longitude)
    { return 0; }

    virtual void calculateDistances(vector_2d_double points);

    virtual void parseDistancesFromResponse(QByteArray* data);

protected:
    // This must be implemented, to create the QNetworkRequest used for the doswnload,
    // containing the appropriate URL and header data.
    virtual QNetworkRequest* makeRoutingRequest(vector_2d_double points) = 0;

    // This should be implemented, returning non-nullptr if the HTTP request will be
    // POST rather than GET. The returned data will be used as POST data.
    virtual QByteArray* makePostData(vector_2d_double points) { return nullptr; }

    void downloadError(QString message);
    void downloadProgress(bool connected, QString text);

    Downloader* downloader;
    vector_2d_double currentPoints;
};


#endif // _NETROUTER_H
