#ifndef _ROUTINGKIT_H
#define _ROUTINGKIT_H

#include "mapdata.h"
#include "router.h"

#include <routingkit/all.h>


typedef RoutingKit::SimpleOSMCarRoutingGraph RKDrivingGraph;
typedef RoutingKit::SimpleOSMPedestrianRoutingGraph RKWalkingGraph;


// The RoutingKit class for parsing/storing map data.
// There are two sorts of interal graph datatypes used, depending on whether the
// routing is by car or by foot (hence the templating).
template<typename ROUTETYPE>
class RoutingKitMapData : public MapData {
public:
    RoutingKitMapData(bool by_car, std::string map_file_path);

    virtual bool loadMap();

    ROUTETYPE graph;
    RoutingKit::ContractionHierarchy hierarchy;

private:
    std::string mapPath;
};



// The RoutingKit distance-calculation class.
template<typename ROUTETYPE>
class RoutingKitRouter : public Router {
public:
    RoutingKitRouter(RoutingKitMapData<ROUTETYPE>* mapdata);
    ~RoutingKitRouter();

    virtual int pointDistance(double from_latitude, double from_longitude,
			      double to_latitude, double to_longitude);

private:
    RoutingKitMapData<ROUTETYPE>* mapData;
};


#endif // _ROUTINGKIT_H
